@@ -84,12 +84,20 @@ setMethod("is.unsorted", "XRawList",
     }
 )
 
+### 'na.last' is pointless (XRawList objects don't contain NAs) so is ignored.
+### 'method' is also ignored at the moment.
 setMethod("order", "XRawList",
-    function(..., na.last=TRUE, decreasing=FALSE)
+    function(..., na.last=TRUE, decreasing=FALSE,
+                  method=c("auto", "shell", "radix"))
     {
-        if (!identical(na.last, TRUE))
-            warning("\"order\" method for XRawList objects ",
-                    "ignores the 'na.last' argument")
+        ## Turn off this warning for now since it triggers spurious warnings
+        ## when calling sort() on an XRawList derivative. The root of the
+        ## problem is inconsistent defaults for 'na.last' between order()
+        ## and sort(), as reported here:
+        ##   https://stat.ethz.ch/pipermail/r-devel/2015-November/072012.html
+        #if (!identical(na.last, TRUE))
+        #    warning("\"order\" method for XRawList objects ",
+        #            "ignores the 'na.last' argument")
         if (!isTRUEorFALSE(decreasing))
             stop("'decreasing' must be TRUE or FALSE")
         ## All arguments in '...' are guaranteed to be XRawList objects.
