@@ -1,2 +1,2 @@
 require("XVector") || stop("unable to load XVector package")
-XVector:::run_unitTests()
+XVector:::.test()
